@@ -535,10 +535,6 @@ where
 
     /// Actually inlines variables.
     pub(super) fn inline(&mut self, e: &mut Expr) {
-        if self.ctx.inline_prevented {
-            return;
-        }
-
         match e {
             Expr::Ident(i) => {
                 //
@@ -577,6 +573,7 @@ where
                     return;
                 }
 
+                // Check witohut cloning
                 if let Some(value) = self.state.vars_for_inlining.get(&i.to_id()) {
                     if self.ctx.is_exact_lhs_of_assign && !is_valid_for_lhs(&value) {
                         return;
